package lib;

import com.sun.jna.*;
import com.sun.jna.ptr.IntByReference;
/**
 * Interface DLL Methoden aus der KommunikationsDLL (DFComDLL.dll) zu DataFox Gerten. 
 * siehe Funktion in der DLL-Beschreibung 
 * @author Harald Kranz 
 *
 */

public interface DFCom extends Library {
	
	/**
	 * Kommunikation ffnen  
	 * siehe DLL-Beschreibung
	 * @param channelNo
	 * @param busNo
	 * @param type
	 * @param comStr
	 * @param comValue
	 * @param timeOut
	 * @return
	 */
	int DFCComOpenIV(int channelNo, int busNo, int type, String comStr, int comValue, int timeOut);
	
	/**
	 * Kommunication beenden 
	 * @param channelNo
	 */
	void DFCComClose(int channelNo); 
	
	
	/**
	 *  Zeichenketten senden
	 * siehe DLL-Beschreibung
	 * @param channelNo
	 * @param busNo
	 * @param delayTime
	 * @param action
	 * @param audio
	 * @param message
	 * @param messageLength
	 * @return
	 */
	int DFCComSendMessage(int channelNo, int busNo, int delayTime, int action, int audio , String message, int messageLength);

	/**
	 * Datensatz lesen  
	 * siehe DLL-Beschreibung
	 * @param channelNo
	 * @param busNo
	 * @param buf
	 * @param length
	 * @param err
	 * @return
	 */
	int DFCReadRecord(int channelNo, int busNo,byte[] buf, IntByReference length, IntByReference err);
	
	/**
	 * Datensatz lesen abschlieen 
	 * siehe DLL-Beschreibung 
	 * @param channelNo
	 * @param busNo
	 * @param err
	 * @return
	 */
	int DFCQuitRecord(int channelNo, int busNo, IntByReference err);
	
	/**
	 *  Lschen des Listenbuffer in der DLL siehe DLL-Beschreibung 
	 * siehe DLL-Beschreibung
	 * @param channelNo
	 */
	void DFCClrListenBuffer(int channelNo);

	/**
	 *  Erstellen der Liste in der DLL
	 * siehe DLL-Beschreibung
	 * @param channelNo
	 * @param listNo
	 * @param lineCount
	 * @param lineSize
	 * @param pucBuf
	 * @param listMemSizeNum
	 * @return
	 */
	int DFCMakeListe(int channelNo, int listNo, int lineCount, int lineSize,byte[] pucBuf, int listMemSizeNum);
			 
    /**
     *  bertragen des SetUp 
	 * siehe DLL-Beschreibung
     * @param channelNo
     * @param busNo
     * @param fileName
     * @param piError
     * @return
     */
	int DFCSetupLaden(int channelNo, int busNo,String fileName, IntByReference piError);

	/**
	 *  bertragen der Listen
	 * siehe DLL-Beschreibung
	 * @param channelNo
	 * @param busNo
	 * @param piError
	 * @return
	 */
	int DFCLoadListen(int channelNo, int busNo,IntByReference piError);
	
	
	/**
	 * Laden der Listenbeschreibung nur der Aufruf das diese gleich abgerufen werden
	 * siehe DLL-Beschreibung
	 * @param channelNo
	 * @param busNo
	 * @param piError
	 * @return
	 */
	int DFCLoadListenbeschreibung(int channelNo, int busNo,IntByReference piError);
	
	/**
	 * Liefert die Anzahl der Listenbeschreibungen zurck.
	 * siehe DLL-Beschreibung
	 * @param channelNo
	 * @return
	 */
	int DFCListBCnt(int channelNo); 
	 
	/**
	 * Auslesen der Anzahl der Felder und der Bezeichnung der Felder aus einer Listenbeschreibung.
	 * siehe DLL-Beschreibung
	 * @param channelNo
	 * @param dataNo
	 * @param dataName
	 * @param fieldCount
	 * @return
	 */
	int DFCListBDatensatz(int channelNo,int dataNo,byte[] dataName, IntByReference fieldCount,IntByReference var);

	/**
	 * Auslesen der Feldbezeichnungen, Feldtypen und Feldlngen einer Listenbeschreibung.
	 * siehe DLL-Beschreibung
	 * @param channelNo
	 * @param dataNo
	 * @param fieldNo
	 * @param fieldName
	 * @param fieldType
	 * @param fieldLength
	 * @return
	 */
	int DFCListBFeld(int channelNo, int dataNo,int fieldNo, byte[] fieldName, IntByReference fieldType, IntByReference fieldLength);
			 
	/**
	 * Laden der Datensatzbeschreibung nur der Aufruf das diese gleich abgerufen werden
	 * siehe DLL-Beschreibung
	 * @param channelNo
	 * @param busNo
	 * @param piError
	 * @return
	 */
	int DFCLoadDatensatzbeschreibung(int channelNo, int busNo,IntByReference piError);
	
	/**
	 * Liefert die Anzahl der Datensatzbeschreibungen zurck.
	 * siehe DLL-Beschreibung
	 * @param channelNo
	 * @return
	 */
	int DFCDatBCnt(int channelNo); 
	 
	/**
	 * Auslesen der Anzahl der Felder und der Bezeichnung der Felder aus einer Datensatzbeschreibung.
	 * siehe DLL-Beschreibung
	 * @param channelNo
	 * @param dataNo
	 * @param dataName
	 * @param fieldCount
	 * @return
	 */
	int DFCDatBDatensatz(int channelNo,int dataNo,byte[] dataName, IntByReference fieldCount);

	/**
	 * Auslesen der Feldbezeichnungen, Feldtypen und Feldlngen einer Datensatzbeschreibung.
	 * siehe DLL-Beschreibung
	 * @param channelNo int 
	 * @param dataNo int 
	 * @param fieldNo int
	 * @param fieldName byte[]
	 * @param fieldType IntByReference
	 * @param fieldLength fieldLength
	 * @return
	 */
	int DFCDatBFeld(int channelNo, int dataNo,int fieldNo, byte[] fieldName, IntByReference fieldType, IntByReference fieldLength);
			 
	
}
