/**
 * @file  ATmega128.cpp
 * @brief Implementierung der Klasse CATmega128.
 */
//////////////////////////////////////////////////////////////////////
//#include "StdAfx.h"
#include "ATmega128.h"
#include <memory.h>
#ifndef _WIN32
#include <string.h>
#endif

CATmega128::CATmega128()
{
	Reset();
}

CATmega128::~CATmega128()
{
}

void CATmega128::Reset()
{
	// Speicher initialisieren
	memset(m_eeprom, 0xFF, sizeof(m_eeprom));
	memset(m_program, 0xFF, sizeof(m_program));
	memset(m_eepromUse, 0, sizeof(m_eepromUse));
	memset(m_programUse, 0, sizeof(m_programUse));
}

void CATmega128::SetEepromUsebit(unsigned long address)
{
	m_eepromUse[address / 32] |= (1 << (address % 32));
}

void CATmega128::SetProgramUsebit(unsigned long address)
{
	m_programUse[address / 32] |= (1 << (address % 32));
}

unsigned char CATmega128::GetEepromUsebit(unsigned long address)
{
	return (m_eepromUse[address / 32] & (1 << (address % 32))) ? 1 : 0;
}

unsigned char CATmega128::GetProgramUsebit(unsigned long address)
{
	return (m_programUse[address / 32] & (1 << (address % 32))) ? 1 : 0;
}

unsigned long CATmega128::GetProgramFirstAddress()
{
	unsigned long address, firstAddress = 0;
	for (address=0; address < ATMEGA128_SIZE_PROGRAM; address++) {

		if (GetProgramUsebit(address)) {

			firstAddress = address;
			break;
		}
	}

	return firstAddress;
}

unsigned long CATmega128::GetProgramLastAddress()
{
	unsigned long address, lastAddress = 0;
	for (address=0; address < ATMEGA128_SIZE_PROGRAM; address++) {

		if (GetProgramUsebit(address)) {

			lastAddress = address;
		}
	}

	return lastAddress;
}

unsigned long CATmega128::GetEepromFirstAddress()
{
	unsigned long address, firstAddress = 0;
	for (address=0; address < ATMEGA128_SIZE_EEPROM; address++) {

		if (GetEepromUsebit(address)) {

			firstAddress = address;
			break;
		}
	}

	return firstAddress;
}

unsigned long CATmega128::GetEepromLastAddress()
{
	unsigned long address, lastAddress = 0;
	for (address=0; address < ATMEGA128_SIZE_EEPROM; address++) {

		if (GetEepromUsebit(address)) {

			lastAddress = address;
		}
	}

	return lastAddress;
}

unsigned long CATmega128::GetProgramSize()
{
	return GetProgramLastAddress() - GetProgramFirstAddress() + 1;
}

