/**
 * @file  ATmega128.h
 * @brief Schnittstelle fuer die Klasse CATmega128.
 */
//////////////////////////////////////////////////////////////////////
#ifndef _ATMEGA128_H_
#define _ATMEGA128_H_

// 128kByte Program - Speicher
#define ATMEGA128_SIZE_PROGRAM     0x20000
#define ATMEGA128_SIZE_BOOTLOADER  0x1000
#define ATMEGA128_SIZE_APPLICATION (ATMEGA128_SIZE_PROGRAM - ATMEGA128_SIZE_BOOTLOADER)

// 4kByte EEPROM - Speicher
#define ATMEGA128_SIZE_EEPROM  0x1000

class CATmega128
{
public:
	CATmega128();
	virtual ~CATmega128();

	// Ruecksetzen
	void Reset();

	// EEPROM
	inline unsigned char *GetMemEeprom(unsigned long address) { 
		if (address >= ATMEGA128_SIZE_EEPROM) 
		{ return 0; }
		return &m_eeprom[address]; 
	}
	inline unsigned char GetEeprom(unsigned long address) { 
		if (address >= ATMEGA128_SIZE_EEPROM) 
		{ return 0; }
		return m_eeprom[address]; 
	}
	inline unsigned long GetEepromRange(unsigned long address, unsigned char *value, unsigned long size) { 
		if ((address + size) >= ATMEGA128_SIZE_EEPROM)
		{ return 0; }
		unsigned long i;
		for (i=address; i < (address + size); i++) {
		
			value[i - address] = m_eeprom[i];
		}
		return (i - address);
	}
	inline void SetEeprom(unsigned long address, unsigned char value) { 
		if (address >= ATMEGA128_SIZE_EEPROM)
		{ return; }
		m_eeprom[address] = value; 
	}
	inline void SetEepromRange(unsigned long address, unsigned char *value, unsigned long size) { 
		if ((address + size) >= ATMEGA128_SIZE_EEPROM)
		{ return; }
		for (unsigned long i=address; i < (address + size); i++) {
		
			m_eeprom[i] = value[i - address];
			SetEepromUsebit(i);
		}
	}
	// PROGRAMFLASH
	inline unsigned char *GetMemProgram(unsigned long address) { 
		if (address >= ATMEGA128_SIZE_PROGRAM) 
		{ return 0; }
		return &m_program[address]; 
	}
	inline unsigned char GetProgram(unsigned long address) { 
		if (address >= ATMEGA128_SIZE_PROGRAM) 
		{ return 0; }
		return m_program[address]; 
	}
	inline unsigned long GetProgramRange(unsigned long address, unsigned char *value, unsigned long size) { 
		if ((address + size) >= ATMEGA128_SIZE_PROGRAM)
		{ return 0; }
		unsigned long i;
		for (i=address; i < (address + size); i++) {
		
			value[i - address] = m_program[i];
		}
		return (i - address);
	}
	inline void SetProgram(unsigned long address, unsigned char value) { 
		if (address >= ATMEGA128_SIZE_PROGRAM)
		{ return; }
		m_program[address] = value;
		SetProgramUsebit(address);
	}
	inline void SetProgramRange(unsigned long address, unsigned char *value, unsigned long size) { 
		if ((address + size) >= ATMEGA128_SIZE_PROGRAM)
		{ return; }
		for (unsigned long i=address; i < (address + size); i++) {
		
			m_program[i] = value[i - address];
			SetProgramUsebit(i);
		}
	}

	// Helper
	unsigned char GetEepromUsebit(unsigned long address);
	unsigned char GetProgramUsebit(unsigned long address);
	unsigned long GetEepromFirstAddress();
	unsigned long GetProgramFirstAddress();
	unsigned long GetEepromLastAddress();
	unsigned long GetProgramLastAddress();
	unsigned long GetProgramSize();

protected:
	unsigned char m_eeprom[ATMEGA128_SIZE_EEPROM];
	unsigned char m_program[ATMEGA128_SIZE_PROGRAM];
	unsigned long m_eepromUse[ATMEGA128_SIZE_EEPROM / 32];
	unsigned long m_programUse[ATMEGA128_SIZE_PROGRAM / 32];
	
	// Helper
	void SetEepromUsebit(unsigned long address);
	void SetProgramUsebit(unsigned long address);
};

#endif

